@@ -477,7 +477,7 @@ photos_base_item_default_update_type_description (PhotosBaseItem *self)
   else if (priv->mime_type != NULL)
     description = g_content_type_get_description (priv->mime_type);
 
-  priv->type_description = description;
+  photos_utils_take_string (&priv->type_description, description);
 }
 
 
@@ -1277,14 +1277,20 @@ photos_base_item_save_buffer_zoom (GObject *source_object, GAsyncResult *res, gp
 {
   GTask *task = G_TASK (user_data);
   PhotosBaseItem *self;
+  PhotosBaseItemPrivate *priv;
   GCancellable *cancellable;
   GError *error;
   GFile *file = NULL;
   GeglBuffer *buffer = GEGL_BUFFER (source_object);
   GeglBuffer *buffer_zoomed = NULL;
   PhotosBaseItemSaveData *data;
+  const gchar *extension;
+  gchar *basename = NULL;
+  gchar *filename = NULL;
 
   self = PHOTOS_BASE_ITEM (g_task_get_source_object (task));
+  priv = self->priv;
+
   cancellable = g_task_get_cancellable (task);
   data = (PhotosBaseItemSaveData *) g_task_get_task_data (task);
 
@@ -1299,7 +1305,11 @@ photos_base_item_save_buffer_zoom (GObject *source_object, GAsyncResult *res, gp
   g_assert_null (data->buffer);
   data->buffer = g_object_ref (buffer_zoomed);
 
-  file = g_file_get_child (data->dir, self->priv->filename);
+  basename = photos_utils_filename_strip_extension (priv->filename);
+  extension = g_strcmp0 (priv->mime_type, "image/png") == 0 ? ".png" : ".jpg";
+  filename = g_strconcat (basename, extension, NULL);
+
+  file = g_file_get_child (data->dir, filename);
   photos_utils_file_create_async (file,
                                   G_FILE_CREATE_NONE,
                                   G_PRIORITY_DEFAULT,
@@ -1308,6 +1318,8 @@ photos_base_item_save_buffer_zoom (GObject *source_object, GAsyncResult *res, gp
                                   g_object_ref (task));
 
  out:
+  g_free (basename);
+  g_free (filename);
   g_clear_object (&buffer_zoomed);
   g_clear_object (&file);
   g_object_unref (task);
@@ -1376,21 +1388,39 @@ photos_base_item_populate_from_cursor (PhotosBaseItem *self, TrackerSparqlCursor
 {
   PhotosBaseItemPrivate *priv = self->priv;
   GTimeVal timeval;
+  const gchar *author;
   const gchar *date_created;
   const gchar *equipment;
   const gchar *flash;
+  const gchar *id;
+  const gchar *identifier;
+  const gchar *mime_type;
   const gchar *mtime;
   const gchar *orientation;
+  const gchar *rdf_type;
+  const gchar *resource_urn;
   const gchar *title;
   const gchar *uri;
+  gchar *filename;
+  gchar *name_fallback;
 
   uri = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URI, NULL);
-  priv->uri = g_strdup ((uri == NULL) ? "" : uri);
+  if (uri == NULL)
+    uri = "";
+  photos_utils_set_string (&priv->uri, uri);
+
+  id = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URN, NULL);
+  photos_utils_set_string (&priv->id, id);
+
+  identifier = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_IDENTIFIER, NULL);
+  photos_utils_set_string (&priv->identifier, identifier);
+
+  author = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_AUTHOR, NULL);
+  photos_utils_set_string (&priv->author, author);
+
+  resource_urn = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_RESOURCE_URN, NULL);
+  photos_utils_set_string (&priv->resource_urn, resource_urn);
 
-  priv->id = g_strdup (tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URN, NULL));
-  priv->identifier = g_strdup (tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_IDENTIFIER, NULL));
-  priv->author = g_strdup (tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_AUTHOR, NULL));
-  priv->resource_urn = g_strdup (tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_RESOURCE_URN, NULL));
   priv->favorite = tracker_sparql_cursor_get_boolean (cursor, PHOTOS_QUERY_COLUMNS_RESOURCE_FAVORITE);
 
   mtime = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_MTIME, NULL);
@@ -1402,8 +1432,12 @@ photos_base_item_populate_from_cursor (PhotosBaseItem *self, TrackerSparqlCursor
   else
     priv->mtime = g_get_real_time () / 1000000;
 
-  priv->mime_type = g_strdup (tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_MIME_TYPE, NULL));
-  priv->rdf_type = g_strdup (tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_RDF_TYPE, NULL));
+  mime_type = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_MIME_TYPE, NULL);
+  photos_utils_set_string (&priv->mime_type, mime_type);
+
+  rdf_type = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_RDF_TYPE, NULL);
+  photos_utils_set_string (&priv->rdf_type, rdf_type);
+
   photos_base_item_update_info_from_type (self);
 
   date_created = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_DATE_CREATED, NULL);
@@ -1422,11 +1456,12 @@ photos_base_item_populate_from_cursor (PhotosBaseItem *self, TrackerSparqlCursor
 
   if (title == NULL)
     title = "";
-  priv->name = g_strdup (title);
+  photos_utils_set_string (&priv->name, title);
 
-  priv->filename = g_strdup (tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_FILENAME, NULL));
-  if ((priv->filename == NULL || priv->filename[0] == '\0') && !priv->collection)
-    priv->filename = PHOTOS_BASE_ITEM_GET_CLASS (self)->create_filename_fallback (self);
+  filename = g_strdup (tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_FILENAME, NULL));
+  if ((filename == NULL || filename[0] == '\0') && !priv->collection)
+    filename = PHOTOS_BASE_ITEM_GET_CLASS (self)->create_filename_fallback (self);
+  photos_utils_take_string (&priv->filename, filename);
 
   priv->width = tracker_sparql_cursor_get_integer (cursor, PHOTOS_QUERY_COLUMNS_WIDTH);
   priv->height = tracker_sparql_cursor_get_integer (cursor, PHOTOS_QUERY_COLUMNS_HEIGHT);
@@ -1445,7 +1480,9 @@ photos_base_item_populate_from_cursor (PhotosBaseItem *self, TrackerSparqlCursor
   flash = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_FLASH, NULL);
   priv->flash = g_quark_from_string (flash);
 
-  priv->name_fallback = PHOTOS_BASE_ITEM_GET_CLASS (self)->create_name_fallback (self);
+  name_fallback = PHOTOS_BASE_ITEM_GET_CLASS (self)->create_name_fallback (self);
+  photos_utils_take_string (&priv->name_fallback, name_fallback);
+
   photos_base_item_refresh_icon (self);
 }
 
