@@ -118,6 +118,8 @@ photos_view_container_item_activated (PhotosViewContainer *self, const gchar * i
 {
   GObject *object;
 
+  g_clear_pointer (&self->current_path, (GDestroyNotify) gtk_tree_path_free);
+
   self->current_path = gtk_tree_path_copy (path);
   object = photos_base_manager_get_object_by_id (self->item_mngr, id);
 
@@ -164,6 +166,12 @@ photos_view_container_query_status_changed (PhotosViewContainer *self, gboolean
 static void
 photos_view_container_select_all (PhotosViewContainer *self)
 {
+  PhotosWindowMode mode;
+
+  mode = photos_mode_controller_get_window_mode (self->mode_cntrlr);
+  if (self->mode != mode)
+    return;
+
   photos_selection_controller_set_selection_mode (self->sel_cntrlr, TRUE);
   gd_main_view_select_all (self->view);
 }
@@ -477,6 +485,24 @@ photos_view_container_new (PhotosWindowMode mode, const gchar *name)
 }
 
 
+void
+photos_view_container_activate_result (PhotosViewContainer *self)
+{
+  GtkTreeIter iter;
+
+  if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (self->model), &iter))
+    {
+      GtkTreePath *path;
+      GtkWidget *generic_view;
+
+      path = gtk_tree_model_get_path (GTK_TREE_MODEL (self->model), &iter);
+      generic_view = gd_main_view_get_generic_view (self->view);
+      gtk_icon_view_item_activated (GTK_ICON_VIEW (generic_view), path);
+      gtk_tree_path_free (path);
+    }
+}
+
+
 GtkTreePath *
 photos_view_container_get_current_path (PhotosViewContainer *self)
 {
